@@ -12,4 +12,4 @@
 # copyright notice, and modified files need to carry a notice indicating
 # that they have been altered from the originals.
 
-"""Qiskit IBMQ integration tests."""
+"""Tests for IBM Quantum Provider."""
